==> arrow-docs-0.8.0-sources.jar: arrow/optics/Inventory$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Inventory`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Inventory`, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get()= arrow.optics.Iso(
  get = { inventory: `arrow`.`optics`.`Inventory` -> inventory.item },
  reverseGet = { `arrow`.`optics`.`Inventory`(it) }
)

inline val `arrow`.`optics`.`Inventory`.Companion.item: arrow.optics.Lens<`arrow`.`optics`.`Inventory`, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get()= arrow.optics.Lens(
  get = { inventory: `arrow`.`optics`.`Inventory` -> inventory.`item` },
  set = { value: `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`> ->
    { inventory: `arrow`.`optics`.`Inventory` ->
      inventory.copy(`item` = value)
    }
  }
)



inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Lens<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Lens<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Optional<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Optional<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Getter<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Setter<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Traversal<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Fold<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item

==> arrow-docs-0.9.0-sources.jar: arrow/optics/Inventory$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Inventory`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Inventory`, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get()= arrow.optics.Iso(
  get = { inventory: `arrow`.`optics`.`Inventory` -> inventory.item },
  reverseGet = { `arrow`.`optics`.`Inventory`(it) }
)

inline val `arrow`.`optics`.`Inventory`.Companion.item: arrow.optics.Lens<`arrow`.`optics`.`Inventory`, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get()= arrow.optics.Lens(
  get = { inventory: `arrow`.`optics`.`Inventory` -> inventory.`item` },
  set = { inventory: `arrow`.`optics`.`Inventory`, value: `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`> -> inventory.copy(`item` = value) }
)



inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Lens<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Lens<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Optional<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Optional<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Getter<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Setter<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Traversal<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Inventory`>.item: arrow.optics.Fold<S, `arrow`.`core`.`Either`<`arrow`.`optics`.`OutOfPacks`, `arrow`.`optics`.`HealthPack`>> inline get() = this + `arrow`.`optics`.`Inventory`.item
